==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/ParaView/vtkPVInitialize.cxx <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVInitialize.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkPVInitialize.h"

#include "vtkObjectFactory.h"
#include "vtkPVDefaultModules.h"
#include "vtkPVWindow.h"

//----------------------------------------------------------------------------
vtkStandardNewMacro(vtkPVInitialize);
vtkCxxRevisionMacro(vtkPVInitialize, "1.1.2.1");

//----------------------------------------------------------------------------
void vtkPVInitialize::Initialize(vtkPVWindow* win)
{
  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardSourceInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardFilterInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardReaderInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardManipulators);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardWriters);
}

//----------------------------------------------------------------------------
void vtkPVInitialize::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}

==> paraview-v1.0.1.zip: paraview-v1.0.1/ParaView/ParaView/vtkPVInitialize.cxx <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVInitialize.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkPVInitialize.h"

#include "vtkObjectFactory.h"
//#include "vtkPVDefaultModules.h"
#include "vtkPVGeneratedModules.h"
#include "vtkPVWindow.h"

//----------------------------------------------------------------------------
vtkStandardNewMacro(vtkPVInitialize);
vtkCxxRevisionMacro(vtkPVInitialize, "1.3");

//----------------------------------------------------------------------------
void vtkPVInitialize::Initialize(vtkPVWindow* win)
{
  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardSourcesInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardFiltersInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardReadersInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardManipulatorsInterfaces);

  win->ReadSourceInterfacesFromString(
    vtkPVInitialize::StandardWritersInterfaces);
}

//----------------------------------------------------------------------------
void vtkPVInitialize::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}
